@@ -131,7 +131,7 @@ Status S3FileSystem::connect_impl() {
 Status S3FileSystem::create_file_impl(const Path& file, FileWriterPtr* writer,
                                       const FileWriterOptions* opts) {
     GET_KEY(key, file);
-    *writer = std::make_unique<S3FileWriter>(key, get_client(), _s3_conf, getSPtr());
+    *writer = std::make_unique<S3FileWriter>(key, get_client(), _s3_conf, getSPtr(), opts);
     return Status::OK();
 }
 
@@ -526,10 +526,10 @@ Status S3FileSystem::get_key(const Path& path, std::string* key) const {
 
 template <typename AwsOutcome>
 std::string S3FileSystem::error_msg(const std::string& key, const AwsOutcome& outcome) const {
-    return fmt::format("(endpoint: {}, bucket: {}, key:{}, {}), {}, error code {}",
+    return fmt::format("(endpoint: {}, bucket: {}, key:{}, {}), {}, error code {}, request id {}",
                        _s3_conf.endpoint, _s3_conf.bucket, key,
                        outcome.GetError().GetExceptionName(), outcome.GetError().GetMessage(),
-                       outcome.GetError().GetResponseCode());
+                       outcome.GetError().GetResponseCode(), outcome.GetError().GetRequestId());
 }
 
 std::string S3FileSystem::error_msg(const std::string& key, const std::string& err) const {
