@@ -73,7 +73,11 @@ Status FullCompaction::execute_compact_impl() {
     // 3. set state to success
     _state = CompactionState::SUCCESS;
 
-    // 4. set cumulative point
+    // 4. set cumulative level
+    _tablet->cumulative_compaction_policy()->update_compaction_level(_tablet.get(), _input_rowsets,
+                                                                     _output_rowset);
+
+    // 5. set cumulative point
     Version last_version = _input_rowsets.back()->version();
     _tablet->cumulative_compaction_policy()->update_cumulative_point(_tablet.get(), _input_rowsets,
                                                                      _output_rowset, last_version);
