@@ -322,7 +322,10 @@ private:
         return 0;
     }
 
-    bool _need_read_key_data(ColumnId cid, vectorized::MutableColumnPtr& column, size_t nrows_read);
+    bool _no_need_read_key_data(ColumnId cid, vectorized::MutableColumnPtr& column,
+                                size_t nrows_read);
+
+    bool _has_delete_predicate(ColumnId cid);
 
     class BitmapRangeIterator;
     class BackwardBitmapRangeIterator;
