@@ -290,6 +290,13 @@ Status TxnManager::commit_txn(OlapMeta* meta, TPartitionId partition_id,
     do {
         // get tx
         std::shared_lock rdlock(_get_txn_map_lock(transaction_id));
+        auto rs_pb = rowset_ptr->rowset_meta()->get_rowset_pb();
+        // TODO(dx): remove log after fix partition id eq 0 bug
+        if (!rs_pb.has_partition_id() || rs_pb.partition_id() == 0) {
+            rowset_ptr->rowset_meta()->set_partition_id(partition_id);
+            LOG(WARNING) << "cant get partition id from rs pb, get from func arg partition_id="
+                         << partition_id;
+        }
         txn_tablet_map_t& txn_tablet_map = _get_txn_tablet_map(transaction_id);
         auto it = txn_tablet_map.find(key);
         if (it == txn_tablet_map.end()) {
@@ -335,8 +342,9 @@ Status TxnManager::commit_txn(OlapMeta* meta, TPartitionId partition_id,
     // save meta need access disk, it maybe very slow, so that it is not in global txn lock
     // it is under a single txn lock
     if (!is_recovery) {
-        Status save_status = RowsetMetaManager::save(meta, tablet_uid, rowset_ptr->rowset_id(),
-                                                     rowset_ptr->rowset_meta()->get_rowset_pb());
+        Status save_status =
+                RowsetMetaManager::save(meta, tablet_uid, rowset_ptr->rowset_id(),
+                                        rowset_ptr->rowset_meta()->get_rowset_pb(), false);
         DBUG_EXECUTE_IF("TxnManager.RowsetMetaManager.save_wait", {
             if (auto wait = dp->param<int>("duration", 0); wait > 0) {
                 LOG_WARNING("TxnManager.RowsetMetaManager.save_wait").tag("wait ms", wait);
@@ -614,8 +622,8 @@ Status TxnManager::delete_txn(OlapMeta* meta, TPartitionId partition_id,
                                         : "0");
             }
         }
+        it->second.erase(load_itr);
     }
-    it->second.erase(tablet_info);
     if (it->second.empty()) {
         txn_tablet_map.erase(it);
         _clear_txn_partition_map_unlocked(transaction_id, partition_id);
