@@ -49,23 +49,23 @@ class time_zone;
         serialize_one_cell_to_json(column, i, bw, options);                   \
     }
 
-#define DESERIALIZE_COLUMN_FROM_JSON_VECTOR()                                                      \
-    for (int i = 0; i < slices.size(); ++i) {                                                      \
-        if (Status st = deserialize_one_cell_from_json(column, slices[i], options, nesting_level); \
-            st != Status::OK()) {                                                                  \
-            return st;                                                                             \
-        }                                                                                          \
-        ++*num_deserialized;                                                                       \
+#define DESERIALIZE_COLUMN_FROM_JSON_VECTOR()                                       \
+    for (int i = 0; i < slices.size(); ++i) {                                       \
+        if (Status st = deserialize_one_cell_from_json(column, slices[i], options); \
+            st != Status::OK()) {                                                   \
+            return st;                                                              \
+        }                                                                           \
+        ++*num_deserialized;                                                        \
     }
 
-#define DESERIALIZE_COLUMN_FROM_HIVE_TEXT_VECTOR()                                      \
-    for (int i = 0; i < slices.size(); ++i) {                                           \
-        if (Status st = deserialize_one_cell_from_hive_text(column, slices[i], options, \
-                                                            nesting_level);             \
-            st != Status::OK()) {                                                       \
-            return st;                                                                  \
-        }                                                                               \
-        ++*num_deserialized;                                                            \
+#define DESERIALIZE_COLUMN_FROM_HIVE_TEXT_VECTOR()                                       \
+    for (int i = 0; i < slices.size(); ++i) {                                            \
+        if (Status st = deserialize_one_cell_from_hive_text(                             \
+                    column, slices[i], options, hive_text_complex_type_delimiter_level); \
+            st != Status::OK()) {                                                        \
+            return st;                                                                   \
+        }                                                                                \
+        ++*num_deserialized;                                                             \
     }
 
 namespace doris {
@@ -118,8 +118,10 @@ public:
 
         char escape_char = 0;
 
-        [[nodiscard]] char get_collection_delimiter(int nesting_level) const {
-            CHECK(0 <= nesting_level && nesting_level <= 153);
+        [[nodiscard]] char get_collection_delimiter(
+                int hive_text_complex_type_delimiter_level) const {
+            CHECK(0 <= hive_text_complex_type_delimiter_level &&
+                  hive_text_complex_type_delimiter_level <= 153);
 
             char ans = '\002';
             //https://github.com/apache/hive/blob/master/serde/src/java/org/apache/hadoop/hive/serde2/lazy/LazySerDeParameters.java#L250
@@ -131,33 +133,39 @@ public:
             // 13 (carriage return, CR, \r, ^M),
             // 27 (escape, ESC, \e [GCC only], ^[).
 
-            if (nesting_level == 1) {
+            if (hive_text_complex_type_delimiter_level == 1) {
                 ans = collection_delim;
-            } else if (nesting_level == 2) {
+            } else if (hive_text_complex_type_delimiter_level == 2) {
                 ans = map_key_delim;
-            } else if (nesting_level <= 7) {
+            } else if (hive_text_complex_type_delimiter_level <= 7) {
                 // [3, 7] -> [4, 8]
-                ans = nesting_level + 1;
-            } else if (nesting_level == 8) {
+                ans = hive_text_complex_type_delimiter_level + 1;
+            } else if (hive_text_complex_type_delimiter_level == 8) {
                 // [8] -> [11]
                 ans = 11;
-            } else if (nesting_level <= 21) {
+            } else if (hive_text_complex_type_delimiter_level <= 21) {
                 // [9, 21] -> [14, 26]
-                ans = nesting_level + 5;
-            } else if (nesting_level <= 25) {
+                ans = hive_text_complex_type_delimiter_level + 5;
+            } else if (hive_text_complex_type_delimiter_level <= 25) {
                 // [22, 25] -> [28, 31]
-                ans = nesting_level + 6;
-            } else if (nesting_level <= 153) {
+                ans = hive_text_complex_type_delimiter_level + 6;
+            } else if (hive_text_complex_type_delimiter_level <= 153) {
                 // [26, 153] -> [-128, -1]
-                ans = nesting_level + (-26 - 128);
+                ans = hive_text_complex_type_delimiter_level + (-26 - 128);
             }
 
             return ans;
         }
     };
 
+    // For the NULL value in the complex type, we use the `null` of the lowercase
+    static const std::string NULL_IN_COMPLEX_TYPE;
+
+    // For the NULL value in the ordinary type in csv file format, we use `\N`
+    static const std::string NULL_IN_CSV_FOR_ORDINARY_TYPE;
+
 public:
-    DataTypeSerDe();
+    DataTypeSerDe(int nesting_level = 1) : _nesting_level(nesting_level) {};
     virtual ~DataTypeSerDe();
     // Text serializer and deserializer with formatOptions to handle different text format
     virtual void serialize_one_cell_to_json(const IColumn& column, int row_num, BufferWritable& bw,
@@ -168,30 +176,25 @@ public:
                                           BufferWritable& bw, FormatOptions& options) const = 0;
 
     virtual Status deserialize_one_cell_from_json(IColumn& column, Slice& slice,
-                                                  const FormatOptions& options,
-                                                  int nesting_level = 1) const = 0;
+                                                  const FormatOptions& options) const = 0;
     // deserialize text vector is to avoid virtual function call in complex type nested loop
     virtual Status deserialize_column_from_json_vector(IColumn& column, std::vector<Slice>& slices,
                                                        int* num_deserialized,
-                                                       const FormatOptions& options,
-                                                       int nesting_level = 1) const = 0;
+                                                       const FormatOptions& options) const = 0;
 
-    virtual Status deserialize_one_cell_from_hive_text(IColumn& column, Slice& slice,
-                                                       const FormatOptions& options,
-                                                       int nesting_level = 1) const {
-        return deserialize_one_cell_from_json(column, slice, options, nesting_level);
+    virtual Status deserialize_one_cell_from_hive_text(
+            IColumn& column, Slice& slice, const FormatOptions& options,
+            int hive_text_complex_type_delimiter_level = 1) const {
+        return deserialize_one_cell_from_json(column, slice, options);
     };
-    virtual Status deserialize_column_from_hive_text_vector(IColumn& column,
-                                                            std::vector<Slice>& slices,
-                                                            int* num_deserialized,
-                                                            const FormatOptions& options,
-                                                            int nesting_level = 1) const {
-        return deserialize_column_from_json_vector(column, slices, num_deserialized, options,
-                                                   nesting_level);
+    virtual Status deserialize_column_from_hive_text_vector(
+            IColumn& column, std::vector<Slice>& slices, int* num_deserialized,
+            const FormatOptions& options, int hive_text_complex_type_delimiter_level = 1) const {
+        return deserialize_column_from_json_vector(column, slices, num_deserialized, options);
     };
-    virtual void serialize_one_cell_to_hive_text(const IColumn& column, int row_num,
-                                                 BufferWritable& bw, FormatOptions& options,
-                                                 int nesting_level = 1) const {
+    virtual void serialize_one_cell_to_hive_text(
+            const IColumn& column, int row_num, BufferWritable& bw, FormatOptions& options,
+            int hive_text_complex_type_delimiter_level = 1) const {
         serialize_one_cell_to_json(column, row_num, bw, options);
     }
 
@@ -232,6 +235,12 @@ public:
 
 protected:
     bool _return_object_as_string = false;
+    // This parameter indicates what level the serde belongs to and is mainly used for complex types
+    // The default level is 1, and each time you nest, the level increases by 1,
+    // for example: struct<string>
+    // The _nesting_level of StructSerde is 1
+    // The _nesting_level of StringSerde is 2
+    int _nesting_level = 1;
 };
 
 /// Invert values since Arrow interprets 1 as a non-null value, while doris as a null
