@@ -67,9 +67,9 @@ namespace doris::vectorized {
     M(TypeIndex::Float64, Float64, Float64)
 
 struct DecodeParams {
-    // schema.logicalType.TIMESTAMP.isAdjustedToUTC == false
+    // schema.logicalType.TIMESTAMP.isAdjustedToUTC == true
     static const cctz::time_zone utc0;
-    // schema.logicalType.TIMESTAMP.isAdjustedToUTC == true, we should set the time zone
+    // schema.logicalType.TIMESTAMP.isAdjustedToUTC == false, we should set local time zone
     cctz::time_zone* ctz = nullptr;
     int32_t offset_days = 0;
     int64_t second_mask = 1;
@@ -99,6 +99,8 @@ public:
     template <typename DecimalPrimitiveType>
     void init_decimal_converter(DataTypePtr& data_type);
 
+    void reset_time_scale_if_missing(int scale);
+
     // Write the decoded values batch to doris's column
     virtual Status decode_values(MutableColumnPtr& doris_column, DataTypePtr& data_type,
                                  ColumnSelectVector& select_vector, bool is_dict_filter) = 0;
