@@ -216,5 +216,14 @@ private:
         _counter.num_rows_unselected = 0;
         _counter.num_rows_filtered = 0;
     }
+
+    // enable the file meta cache only when
+    // 1. max_external_file_meta_cache_num is > 0
+    // 2. the file number is less than 1/3 of cache's capacibility
+    // Otherwise, the cache miss rate will be high
+    bool _shoudl_enable_file_meta_cache() {
+        return config::max_external_file_meta_cache_num > 0 &&
+               _ranges.size() < config::max_external_file_meta_cache_num / 3;
+    }
 };
 } // namespace doris::vectorized
