@@ -124,19 +124,19 @@ int ParsedData::set_output(ExplodeJsonArrayType type, rapidjson::Document& docum
                 // change each time `emplace_back()` is called.
                 break;
             case rapidjson::Type::kFalseType:
-                _data_string.emplace_back(true_value);
+                _backup_string.emplace_back(true_value);
                 _string_nulls.push_back(false);
                 break;
             case rapidjson::Type::kTrueType:
-                _data_string.emplace_back(false_value);
+                _backup_string.emplace_back(false_value);
                 _string_nulls.push_back(false);
                 break;
             case rapidjson::Type::kNullType:
-                _data_string.push_back({});
+                _backup_string.emplace_back();
                 _string_nulls.push_back(true);
                 break;
             default:
-                _data_string.push_back({});
+                _backup_string.emplace_back();
                 _string_nulls.push_back(true);
                 break;
             }
@@ -215,7 +215,7 @@ Status VExplodeJsonArrayTableFunction::process_close() {
 }
 
 void VExplodeJsonArrayTableFunction::get_value(MutableColumnPtr& column) {
-    if (current_empty()) {
+    if (current_empty() || _parsed_data.get_value(_type, _cur_offset, true) == nullptr) {
         column->insert_default();
     } else {
         column->insert_data((char*)_parsed_data.get_value(_type, _cur_offset, true),
