@@ -420,9 +420,9 @@ Status VUnionIterator::current_block_row_locations(std::vector<RowLocation>* loc
 RowwiseIteratorUPtr new_merge_iterator(std::vector<RowwiseIteratorUPtr>&& inputs,
                                        int sequence_id_idx, bool is_unique, bool is_reverse,
                                        uint64_t* merged_rows) {
-    if (inputs.size() == 1) {
-        return std::move(inputs[0]);
-    }
+    // when the size of inputs is 1, we also need to use VMergeIterator, because the
+    // next_block_view function only be implemented in VMergeIterator. The reason why
+    // the size of inputs is 1 is that the segment was filtered out by zone map or others.
     return std::make_unique<VMergeIterator>(std::move(inputs), sequence_id_idx, is_unique,
                                             is_reverse, merged_rows);
 }
