@@ -1111,13 +1111,13 @@ public:
         return (daynr() - rhs.daynr()) * SECOND_PER_HOUR * HOUR_PER_DAY + time_part_diff(rhs);
     }
 
+    // used by INT microseconds_diff(DATETIME enddate, DATETIME startdate)
+    // return it's int type, so shouldn't have any limit.
+    // when used by TIME TIMEDIFF(DATETIME expr1, DATETIME expr2), it's return time type, should have limited.
     template <typename RHS>
-    double microsecond_diff(const RHS& rhs) const {
+    int64_t microsecond_diff(const RHS& rhs) const {
         int64_t diff_m = (daynr() - rhs.daynr()) * SECOND_PER_HOUR * HOUR_PER_DAY * 1000 * 1000 +
                          time_part_diff_microsecond(rhs);
-        if (diff_m > (int64_t)3020399 * 1000 * 1000) {
-            diff_m = (int64_t)3020399 * 1000 * 1000;
-        }
         return diff_m;
     }
 
