@@ -268,7 +268,7 @@ TEST_F(SegCompactionTest, SegCompactionThenRead) {
             sleep(1);
         }
 
-        rowset = rowset_writer->build();
+        EXPECT_EQ(Status::OK(), rowset_writer->build(rowset));
         std::vector<std::string> ls;
         ls.push_back("10047_0.dat");
         ls.push_back("10047_1.dat");
@@ -464,7 +464,7 @@ TEST_F(SegCompactionTest, SegCompactionInterleaveWithBig_ooooOOoOooooooooO) {
             sleep(1);
         }
 
-        rowset = rowset_writer->build();
+        EXPECT_EQ(Status::OK(), rowset_writer->build(rowset));
         std::vector<std::string> ls;
         // ooooOOoOooooooooO
         ls.push_back("10048_0.dat"); // oooo
@@ -590,7 +590,7 @@ TEST_F(SegCompactionTest, SegCompactionInterleaveWithBig_OoOoO) {
             sleep(1);
         }
 
-        rowset = rowset_writer->build();
+        EXPECT_EQ(Status::OK(), rowset_writer->build(rowset));
         std::vector<std::string> ls;
         ls.push_back("10049_0.dat"); // O
         ls.push_back("10049_1.dat"); // o
@@ -769,7 +769,7 @@ TEST_F(SegCompactionTest, SegCompactionThenReadUniqueTableSmall) {
         EXPECT_EQ(Status::OK(), s);
         sleep(1);
 
-        rowset = rowset_writer->build();
+        EXPECT_EQ(Status::OK(), rowset_writer->build(rowset));
         std::vector<std::string> ls;
         ls.push_back("10051_0.dat");
         ls.push_back("10051_1.dat");
@@ -1003,7 +1003,7 @@ TEST_F(SegCompactionTest, SegCompactionThenReadAggTableSmall) {
         EXPECT_EQ(Status::OK(), s);
         sleep(1);
 
-        rowset = rowset_writer->build();
+        EXPECT_EQ(Status::OK(), rowset_writer->build(rowset));
         std::vector<std::string> ls;
         ls.push_back("10052_0.dat");
         ls.push_back("10052_1.dat");
