@@ -480,21 +480,16 @@ TEST(TEST_VEXPR, LITERALTEST) {
         uint8_t hour = 9;
         uint8_t minute = 12;
         uint8_t second = 46;
-        uint32_t microsecond = 999999;
+        uint32_t microsecond = 999999; // target scale is 4, so the microsecond will be rounded up
         DateV2Value<DateTimeV2ValueType> datetime_v2;
         datetime_v2.set_time(year, month, day, hour, minute, second, microsecond);
         std::string date = datetime_v2.debug_string();
 
-        __uint64_t dt;
-        memcpy(&dt, &datetime_v2, sizeof(__uint64_t));
         VLiteral literal(create_literal<TYPE_DATETIMEV2, std::string>(date, 4));
         Block block;
         int ret = -1;
-        literal.execute(nullptr, &block, &ret);
-        auto ctn = block.safe_get_by_position(ret);
-        auto v = (*ctn.column)[0].get<__uint64_t>();
-        EXPECT_EQ(v, dt);
-        EXPECT_EQ("1997-11-18 09:12:46.9999", literal.value());
+        EXPECT_TRUE(literal.execute(nullptr, &block, &ret).ok());
+        EXPECT_EQ("1997-11-18 09:12:47.0000", literal.value());
     }
     // date
     {
