@@ -362,4 +362,24 @@ public class IntLiteral extends LiteralExpr {
     public int hashCode() {
         return 31 * super.hashCode() + Long.hashCode(value);
     }
+
+    @Override
+    public void setupParamFromBinary(ByteBuffer data) {
+        switch (type.getPrimitiveType()) {
+            case TINYINT:
+                value = data.get();
+                break;
+            case SMALLINT:
+                value = data.getChar();
+                break;
+            case INT:
+                value = data.getInt();
+                break;
+            case BIGINT:
+                value = data.getLong();
+                break;
+            default:
+                Preconditions.checkState(false);
+        }
+    }
 }
