@@ -38,6 +38,7 @@ import org.apache.doris.nereids.trees.expressions.functions.scalar.GroupingScala
 import org.apache.doris.nereids.trees.plans.Plan;
 import org.apache.doris.nereids.trees.plans.algebra.Generate;
 import org.apache.doris.nereids.trees.plans.logical.LogicalAggregate;
+import org.apache.doris.nereids.trees.plans.logical.LogicalDeferMaterializeOlapScan;
 import org.apache.doris.nereids.trees.plans.logical.LogicalFilter;
 import org.apache.doris.nereids.trees.plans.logical.LogicalOlapScan;
 import org.apache.doris.nereids.trees.plans.logical.LogicalSort;
@@ -181,7 +182,8 @@ public class CheckAfterRewrite extends OneAnalysisRuleFactory {
     private void checkMatchIsUsedCorrectly(Plan plan) {
         if (plan.getExpressions().stream().anyMatch(
                 expression -> expression instanceof Match)) {
-            if (plan instanceof LogicalFilter && plan.child(0) instanceof LogicalOlapScan) {
+            if (plan instanceof LogicalFilter && (plan.child(0) instanceof LogicalOlapScan
+                    || plan.child(0) instanceof LogicalDeferMaterializeOlapScan)) {
                 return;
             } else {
                 throw new AnalysisException(String.format(
