@@ -23,6 +23,7 @@ import org.apache.doris.nereids.trees.expressions.visitor.ExpressionVisitor;
 import org.apache.doris.nereids.types.DataType;
 
 import com.google.common.base.Preconditions;
+import com.google.common.collect.ImmutableList;
 
 import java.util.List;
 import java.util.Objects;
@@ -32,11 +33,31 @@ import java.util.Objects;
  */
 public class Cast extends Expression implements UnaryExpression {
 
+    // CAST can be from SQL Query or Type Coercion.
+    private final boolean isExplicitType;
+
     private final DataType targetType;
 
+    public Cast(Expression child, DataType targetType, boolean isExplicitType) {
+        super(ImmutableList.of(child));
+        this.targetType = Objects.requireNonNull(targetType, "targetType can not be null");
+        this.isExplicitType = isExplicitType;
+    }
+
     public Cast(Expression child, DataType targetType) {
+        super(ImmutableList.of(child));
+        this.targetType = Objects.requireNonNull(targetType, "targetType can not be null");
+        this.isExplicitType = false;
+    }
+
+    private Cast(List<Expression> child, DataType targetType, boolean isExplicitType) {
         super(child);
         this.targetType = Objects.requireNonNull(targetType, "targetType can not be null");
+        this.isExplicitType = isExplicitType;
+    }
+
+    public boolean isExplicitType() {
+        return isExplicitType;
     }
 
     @Override
@@ -66,7 +87,7 @@ public class Cast extends Expression implements UnaryExpression {
     @Override
     public Cast withChildren(List<Expression> children) {
         Preconditions.checkArgument(children.size() == 1);
-        return new Cast(children.get(0), getDataType());
+        return new Cast(children, targetType, isExplicitType);
     }
 
     @Override
