@@ -48,42 +48,38 @@ public class LogicalProject<CHILD_TYPE extends Plan> extends LogicalUnary<CHILD_
 
     private final List<NamedExpression> projects;
     private final List<NamedExpression> excepts;
-
+    private final boolean isDistinct;
     // For project nodes under union, erasure cannot be configured, so add this flag.
     private final boolean canEliminate;
 
-    private final boolean isDistinct;
-
     public LogicalProject(List<NamedExpression> projects, CHILD_TYPE child) {
-        this(projects, ImmutableList.of(), true, child, false);
+        this(projects, ImmutableList.of(), false, true, child);
     }
 
+    /**
+     * only for test.
+     */
     public LogicalProject(List<NamedExpression> projects, List<NamedExpression> excepts, CHILD_TYPE child) {
-        this(projects, excepts, true, child, false);
+        this(projects, excepts, false, true, child);
+    }
+
+    public LogicalProject(List<NamedExpression> projects, boolean isDistinct, CHILD_TYPE child) {
+        this(projects, ImmutableList.of(), isDistinct, true, child);
     }
 
     public LogicalProject(List<NamedExpression> projects, List<NamedExpression> excepts,
-                          boolean canEliminate, CHILD_TYPE child) {
-        this(projects, excepts, canEliminate, Optional.empty(), Optional.empty(), child, false);
-    }
-
-    public LogicalProject(List<NamedExpression> projects, CHILD_TYPE child, boolean isDistinct) {
-        this(projects, ImmutableList.of(), true, child, isDistinct);
-    }
-
-    public LogicalProject(List<NamedExpression> projects, List<NamedExpression> excepts, CHILD_TYPE child,
-                            boolean isDistinct) {
-        this(projects, excepts, true, child, isDistinct);
+            boolean isDistinct, CHILD_TYPE child) {
+        this(projects, excepts, isDistinct, true, child);
     }
 
     private LogicalProject(List<NamedExpression> projects, List<NamedExpression> excepts,
-                          boolean canEliminate, CHILD_TYPE child, boolean isDistinct) {
-        this(projects, excepts, canEliminate, Optional.empty(), Optional.empty(), child, isDistinct);
+            boolean isDistinct, boolean canEliminate, CHILD_TYPE child) {
+        this(projects, excepts, isDistinct, canEliminate, Optional.empty(), Optional.empty(), child);
     }
 
-    private LogicalProject(List<NamedExpression> projects, List<NamedExpression> excepts, boolean canEliminate,
-            Optional<GroupExpression> groupExpression, Optional<LogicalProperties> logicalProperties,
-            CHILD_TYPE child, boolean isDistinct) {
+    private LogicalProject(List<NamedExpression> projects, List<NamedExpression> excepts, boolean isDistinct,
+            boolean canEliminate, Optional<GroupExpression> groupExpression,
+            Optional<LogicalProperties> logicalProperties, CHILD_TYPE child) {
         super(PlanType.LOGICAL_PROJECT, groupExpression, logicalProperties, child);
         Preconditions.checkArgument(projects != null, "projects can not be null");
         // only ColumnPrune rule may produce empty projects, this happens in rewrite phase
@@ -94,8 +90,8 @@ public class LogicalProject<CHILD_TYPE extends Plan> extends LogicalUnary<CHILD_
                 ? ImmutableList.of(ExpressionUtils.selectMinimumColumn(child.getOutput()))
                 : projects;
         this.excepts = ImmutableList.copyOf(excepts);
-        this.canEliminate = canEliminate;
         this.isDistinct = isDistinct;
+        this.canEliminate = canEliminate;
     }
 
     /**
@@ -172,43 +168,43 @@ public class LogicalProject<CHILD_TYPE extends Plan> extends LogicalUnary<CHILD_
     @Override
     public LogicalProject<Plan> withChildren(List<Plan> children) {
         Preconditions.checkArgument(children.size() == 1);
-        return new LogicalProject<>(projects, excepts, canEliminate, children.get(0), isDistinct);
+        return new LogicalProject<>(projects, excepts, isDistinct, canEliminate, children.get(0));
     }
 
     @Override
     public LogicalProject<Plan> withGroupExpression(Optional<GroupExpression> groupExpression) {
-        return new LogicalProject<>(projects, excepts, canEliminate,
-                groupExpression, Optional.of(getLogicalProperties()), child(), isDistinct);
+        return new LogicalProject<>(projects, excepts, isDistinct, canEliminate,
+                groupExpression, Optional.of(getLogicalProperties()), child());
     }
 
     @Override
     public Plan withGroupExprLogicalPropChildren(Optional<GroupExpression> groupExpression,
             Optional<LogicalProperties> logicalProperties, List<Plan> children) {
         Preconditions.checkArgument(children.size() == 1);
-        return new LogicalProject<>(projects, excepts, canEliminate,
-                groupExpression, logicalProperties, children.get(0), isDistinct);
+        return new LogicalProject<>(projects, excepts, isDistinct, canEliminate,
+                groupExpression, logicalProperties, children.get(0));
     }
 
     public LogicalProject<Plan> withEliminate(boolean isEliminate) {
-        return new LogicalProject<>(projects, excepts, isEliminate, child(), isDistinct);
+        return new LogicalProject<>(projects, excepts, isDistinct, isEliminate, child());
     }
 
     public LogicalProject<Plan> withProjects(List<NamedExpression> projects) {
-        return new LogicalProject<>(projects, excepts, canEliminate, child(), isDistinct);
+        return new LogicalProject<>(projects, excepts, isDistinct, canEliminate, child());
     }
 
     public LogicalProject<Plan> withProjectsAndChild(List<NamedExpression> projects, Plan child) {
-        return new LogicalProject<>(projects, excepts, canEliminate, child, isDistinct);
-    }
-
-    public boolean canEliminate() {
-        return canEliminate;
+        return new LogicalProject<>(projects, excepts, isDistinct, canEliminate, child);
     }
 
     public boolean isDistinct() {
         return isDistinct;
     }
 
+    public boolean canEliminate() {
+        return canEliminate;
+    }
+
     @Override
     public List<NamedExpression> getOutputs() {
         return projects;
@@ -230,10 +226,4 @@ public class LogicalProject<CHILD_TYPE extends Plan> extends LogicalUnary<CHILD_
         logicalProject.put("Properties", properties);
         return logicalProject;
     }
-
-    public LogicalProject<Plan> readFromJson(JSONObject logicalProject) {
-
-        return new LogicalProject<>(ImmutableList.of(new UnboundStar(ImmutableList.of())),
-            null, null, isDistinct);
-    }
 }
